def get_copyright():
    print("All rights reserved; those responsible for unauthorized reproduction will be prosecuted。")
def get_author():
    print("author(func,prints,copyright):Li Chengze\npublisher:Guo Yanming")