import setuptools
setuptools.setup(
    name='oython',
    version='1.0.0',
    author='Chengze Li',
    author_email='gyms1111@163.com',
    description="oython库，作者:李承泽（正常线路下载失败时，请切换为python原版路线)。",
    long_descripition_content_type="text/markdown",
    url='https://github.com/',
    packages=setuptools.find_packages(),
    classifiers= [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent" ,
    ],
)